@@ -1,5 +1,5 @@
 #
-# $Id: Layer.pm 2011 2015-02-15 17:07:47Z gomor $
+# $Id: Layer.pm 2014 2015-03-04 06:16:57Z gomor $
 #
 package Net::Write::Layer;
 use strict;
@@ -193,6 +193,34 @@ sub _setGetaddrinfoSub {
       return 1;
    }
 
+   # If still not found, we rely on Socket::GetAddrInfo()
+   eval("use Socket::GetAddrInfo qw(getaddrinfo);");
+   if ($@) {
+      chomp($@);
+      die("[-] Net::Write: getaddrinfo: not supported, try installing ".
+          "Socket::GetAddrInfo [$@]\n");
+   }
+   else {
+      *{__PACKAGE__.'::nw_getsaddr'} = sub {
+         my ($dest, $family, $protocol, $socktype) = @_;
+
+         #print STDERR "*** Fallback on Socket::GetAddrInfo support\n";
+
+         my %hints = ( family => $family );
+         my ($err, @res) = Socket::GetAddrInfo::getaddrinfo($dest, "", \%hints);
+         if ($err) {
+            return _croak("@{[(caller(0))[3]]}: getaddrinfo: $err");
+         }
+
+         my $ai = $res[0];
+         if (! defined($ai)) {
+            return _croak("@{[(caller(0))[3]]}: getaddrinfo: ai undefined");
+         }
+
+         return $ai->{addr};  # return sockaddr struct
+      };
+   }
+
    return 1;
 }
 
