@@ -1,5 +1,5 @@
 #
-# $Id: Layer3.pm 2005 2015-01-23 06:56:13Z gomor $
+# $Id: Layer3.pm 2008 2015-02-10 06:33:53Z gomor $
 #
 package Net::Write::Layer3;
 use strict;
@@ -50,6 +50,10 @@ sub _setIpHdrincl {
       return setsockopt($sock, NW_IPPROTO_IP, NW_IP_HDRINCL, 1);
    }
    if ($family == NW_AF_INET6) {
+      # Currently, only Linux supports IPHDRINCL for IPv6, no Layer3 sending for others :(
+      if ($^O ne 'linux') {
+         die("[-] @{[(caller(0))[3]]}: IPHDRINCL only supported on Linux\n");
+      }
       return setsockopt($sock, NW_IPPROTO_IPv6, NW_IP_HDRINCL, 1);
    }
    return;
